@@ -100,7 +100,6 @@ class RESTClient:
                      data=None,
                      files=None,
                      verify=False,
-                     extended_header: bool = False,
                      custom_header=None,
                      cookies=None,
                      request_timeout=None):
@@ -120,7 +119,6 @@ class RESTClient:
         :param data: json data
         :param files: "files: {'licenseFile': (License.name, f)}"
         :param verify: Bool
-        :param extended_header: Add 'UserAgentInternal': 'webfrontend/1.0' to the header
         :param custom_header: Use specified header
         :param request_timeout: Time in sec.
         :return: requests.request('POST', url=url, headers=HEADER, files=files, verify=False)
@@ -147,11 +145,6 @@ class RESTClient:
         if 'Content-Type' not in self.header:
             self.header['Content-Type'] = 'application/json'
 
-        header_ext = None
-        if extended_header:
-            header_ext = self.header.copy()
-            header_ext['UserAgentInternal'] = 'webfrontend/1.0'
-
         response = 'Invalid requests. Check parameters'
 
         try:
@@ -206,9 +199,7 @@ class RESTClient:
 
                 # For usual 'GET' without query params
                 header = self.header
-                if extended_header:  # replace default header with extended one
-                    header = header_ext
-                elif custom_header:
+                if custom_header:
                     header = custom_header
 
                 logger.info(f'{method} ' + link)
@@ -270,7 +261,6 @@ class RESTClient:
         return self.send_request('GET',
                                  url=url,
                                  query_params=query_params,
-                                 extended_header=extend_header,
                                  cookies=cookies,
                                  request_timeout=request_timeout)
 
@@ -289,7 +279,6 @@ class RESTClient:
                                  query_params=query_params,
                                  data=data,
                                  files=file,
-                                 extended_header=extend_header,
                                  cookies=cookies,
                                  request_timeout=request_timeout)
 
@@ -298,6 +287,7 @@ class RESTClient:
             url='',
             extend_header=False,
             custom_header=None,
+            data='',
             files='',
             request_timeout=None,
             verify=False):
@@ -316,7 +306,8 @@ class RESTClient:
                                 url=url,
                                 auth=self.auth_basic,
                                 headers=header,
-                                data=files,
+                                data=data,
+                                files=files,
                                 verify=verify,
                                 timeout=request_timeout)
 
@@ -332,7 +323,6 @@ class RESTClient:
                                  url=url,
                                  query_params=query_params,
                                  data=data,
-                                 extended_header=extend_header,
                                  cookies=cookies,
                                  request_timeout=request_timeout)
 
